import { html } from 'htm/preact';
import { Component } from 'preact';
/**
 * A {@linkcode https://developer.mozilla.org/docs/Web/HTML/Element/button <button>}
 * element wrapper that requires 2 clicks within a given time to call the click
 * function. For example to confirm removal of something.
 */
export class ConfirmButton extends Component {
    constructor(props) {
        super(props);
        this.state = {
            timeoutHandle: undefined,
        };
    }
    click = (event) => {
        const { click, preventDefault, timeout } = this.props;
        const { timeoutHandle } = this.state;
        if (preventDefault) {
            event.preventDefault();
        }
        if (timeoutHandle === undefined) {
            this.setState({
                timeoutHandle: window.setTimeout(this.resetTimeout, timeout),
            });
        }
        else {
            click(event);
            this.resetTimeout();
        }
    };
    resetTimeout = () => {
        window.clearTimeout(this.state.timeoutHandle);
        this.setState({ timeoutHandle: undefined });
    };
    render() {
        const timeoutActive = this.state.timeoutHandle !== undefined;
        let text = this.props.text;
        const props = {
            class: this.props.class,
        };
        if (timeoutActive) {
            text = this.props.confirmText;
            props.class = `${props.class} ${this.props.confirmClass}`;
        }
        return html `
      <button ...${this.props.attributes} ...${props} onclick=${this.click}>
        ${text}
      </button>
    `;
    }
}
//# sourceMappingURL=confirm-button.js.map