import { html } from 'htm/preact';
import { Component } from 'preact';
/**
 * A {@linkcode https://developer.mozilla.org/docs/Web/HTML/Element/button <button>}
 * element wrapper that changes its text for a given time after being clicked.
 */
export class FeedbackButton extends Component {
    constructor(props) {
        super(props);
        this.state = {
            currentText: this.props.text,
            timeoutHandle: undefined,
        };
    }
    click = async (event) => {
        if ((await this.props.click(event)) === false) {
            return;
        }
        let { timeoutHandle } = this.state;
        if (timeoutHandle !== undefined) {
            window.clearTimeout(timeoutHandle);
        }
        timeoutHandle = window.setTimeout(() => {
            this.setState({
                currentText: this.props.text,
                timeoutHandle: undefined,
            });
        }, this.props.timeout);
        this.setState({
            currentText: this.props.feedbackText,
            timeoutHandle,
        });
    };
    render() {
        return html `
      <button ...${this.props.attributes} onclick=${this.click}>
        ${this.state.currentText}
      </button>
    `;
    }
}
//# sourceMappingURL=feedback-button.js.map